import Authenticator from './authenticator';
import AuthFinishStep, { AuthFinishStepFn } from './auth-finish-step';
import AuthMessage from './internal/auth-message';
import { AuthResponseStatus } from './internal/auth-response-status';
import Platform from './internal/platform';
import { OtpFinishStep, OtpFinishStepFn, OtpStartStep, OtpStartStepFn } from './otp';
import { InstantLinkRetryStep, InstantLinkRetryStepFn, InstantLinkStartStep, InstantLinkStartStepFn } from './instantlink';
import type { Region } from '@fingerprintjs/fingerprintjs-pro';
import DeviceContextOptions, { BuildConfig } from './device-context-options';
import UserConsentStep, { UserConsentStepFn } from './user-consent-step';
export type AuthMessageHandler = (message: AuthMessage) => Promise<AuthResponseStatus>;
export type PasskeyAlreadyExistCallback = () => Promise<AuthResponseStatus>;
export declare enum DeviceRole {
    Primary = 0,
    Secondary = 1
}
export declare enum MobileAuthImplementation {
    Pixel = "pixel",
    Fetch = "fetch"
}
export default class AuthenticatorBuilder {
    private role;
    private mobileAuthImplementation;
    private authFinishStep?;
    private getDisplayName?;
    private getDeviceIp?;
    private authMessageHandler?;
    private passkeyCreationHandler?;
    private storage?;
    private platform?;
    private otpStartStep?;
    private otpFinishStep?;
    private instantLinkStartStep?;
    private instantLinkRetryStep?;
    private upkEnabled;
    private userConsentStep?;
    private readonly log;
    private deviceContextOptions?;
    constructor();
    withDeviceContext(options: DeviceContextOptions): AuthenticatorBuilder;
    withAuthFinishStep(step: AuthFinishStep | AuthFinishStepFn): AuthenticatorBuilder;
    withDisplayName(displayName: string | (() => string | null) | null): AuthenticatorBuilder;
    withAuthMessageHandler(handler: AuthMessageHandler): AuthenticatorBuilder;
    withStorage(storage: Storage): AuthenticatorBuilder;
    withPlatform(platform: Platform): AuthenticatorBuilder;
    withRole(role: DeviceRole): AuthenticatorBuilder;
    withMobileAuthImplementation(implementation: MobileAuthImplementation): AuthenticatorBuilder;
    withDeviceIpAddress(deviceIp: string | (() => string | null) | null): AuthenticatorBuilder;
    withOtpFallback(startStep: OtpStartStep | OtpStartStepFn, finishStep: OtpFinishStep | OtpFinishStepFn): AuthenticatorBuilder;
    withInstantLinkFallback(startStep: InstantLinkStartStep | InstantLinkStartStepFn, retryStep?: InstantLinkRetryStep | InstantLinkRetryStepFn): AuthenticatorBuilder;
    withUPKEnabled(): this;
    withUniversalProveKey(step?: UserConsentStep | UserConsentStepFn): this;
    getUrlsByBuildConfig(buildConfig?: BuildConfig): [string | undefined, string | undefined];
    getRegionByBuildConfig(buildConfig?: BuildConfig): Region;
    private getFpPromiseInstanceFromOptions;
    withPasskeyAlreadyExistCallback(handler: PasskeyAlreadyExistCallback): AuthenticatorBuilder;
    build(): Authenticator;
}
