"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MobileAuthImplementation = exports.DeviceRole = void 0;
const web_platform_1 = require("./internal/web-platform");
const device_passive_register_step_1 = __importDefault(require("./internal/device-passive-register-step"));
const device_passive_step_1 = __importDefault(require("./internal/device-passive-step"));
const device_passive_verify_step_1 = __importDefault(require("./internal/device-passive-verify-step"));
const mobile_instant_step_1 = __importDefault(require("./internal/mobile-instant-step"));
const mobile_instantlink_step_1 = __importDefault(require("./internal/mobile-instantlink-step"));
const mobile_otp_step_1 = __importDefault(require("./internal/mobile-otp-step"));
const scan_message_step_1 = __importDefault(require("./internal/scan-message-step"));
const user_mobileactive_step_1 = __importDefault(require("./internal/user-mobileactive-step"));
const device_passive_silent_step_1 = __importDefault(require("./internal/device-passive-silent-step"));
const device_passive_stepup_step_1 = __importDefault(require("./internal/device-passive-stepup-step"));
const device_universal_step_1 = __importDefault(require("./internal/device-universal-step"));
const device_universal_redirect_steps_1 = require("./internal/device-universal-redirect-steps");
const main_authenticator_1 = __importDefault(require("./internal/main-authenticator"));
const logger_1 = require("./common/logger");
const settings_1 = __importDefault(require("./internal/settings"));
const device_context_options_1 = require("./device-context-options");
var DeviceRole;
(function (DeviceRole) {
    DeviceRole[DeviceRole["Primary"] = 0] = "Primary";
    DeviceRole[DeviceRole["Secondary"] = 1] = "Secondary";
})(DeviceRole = exports.DeviceRole || (exports.DeviceRole = {}));
var MobileAuthImplementation;
(function (MobileAuthImplementation) {
    MobileAuthImplementation["Pixel"] = "pixel";
    MobileAuthImplementation["Fetch"] = "fetch";
})(MobileAuthImplementation = exports.MobileAuthImplementation || (exports.MobileAuthImplementation = {}));
class AuthenticatorBuilder {
    constructor() {
        this.role = DeviceRole.Primary;
        this.mobileAuthImplementation = MobileAuthImplementation.Fetch;
        this.upkEnabled = false;
        this.log = logger_1.LoggerFactory.getLogger('authenticator-builder');
        if (typeof window !== 'undefined') {
            this.storage = window.localStorage;
            this.platform = new web_platform_1.WebPlatform();
        }
    }
    withDeviceContext(options) {
        this.deviceContextOptions = options;
        return this;
    }
    withAuthFinishStep(step) {
        if (typeof step === 'function') {
            this.authFinishStep = {
                execute: (input) => step(input),
            };
        }
        else {
            this.authFinishStep = step;
        }
        return this;
    }
    withDisplayName(displayName) {
        this.getDisplayName = typeof displayName === 'function' ? displayName : () => displayName;
        return this;
    }
    withAuthMessageHandler(handler) {
        this.authMessageHandler = handler;
        return this;
    }
    withStorage(storage) {
        this.storage = storage;
        return this;
    }
    withPlatform(platform) {
        this.platform = platform;
        return this;
    }
    withRole(role) {
        this.role = role;
        return this;
    }
    withMobileAuthImplementation(implementation) {
        this.mobileAuthImplementation = implementation;
        return this;
    }
    withDeviceIpAddress(deviceIp) {
        this.getDeviceIp = typeof deviceIp === 'function' ? deviceIp : () => deviceIp;
        return this;
    }
    withOtpFallback(startStep, finishStep) {
        if (typeof startStep === 'function') {
            this.otpStartStep = { execute: startStep };
        }
        else {
            this.otpStartStep = startStep;
        }
        if (typeof finishStep === 'function') {
            this.otpFinishStep = { execute: finishStep };
        }
        else {
            this.otpFinishStep = finishStep;
        }
        return this;
    }
    withInstantLinkFallback(startStep, retryStep) {
        if (typeof startStep === 'function') {
            this.instantLinkStartStep = { execute: startStep };
        }
        else {
            this.instantLinkStartStep = startStep;
        }
        if (typeof retryStep === 'function') {
            this.instantLinkRetryStep = { execute: retryStep };
        }
        else {
            this.instantLinkRetryStep = retryStep;
        }
        return this;
    }
    withUPKEnabled() {
        return this.withUniversalProveKey();
    }
    withUniversalProveKey(step) {
        if (!step) {
            this.userConsentStep = { execute: () => Promise.resolve({ consentGranted: true }) };
        }
        else if (typeof step === 'function') {
            this.userConsentStep = { execute: step };
        }
        else {
            this.userConsentStep = step;
        }
        this.upkEnabled = this.userConsentStep != null;
        return this;
    }
    getUrlsByBuildConfig(buildConfig) {
        switch (buildConfig) {
            case device_context_options_1.BuildConfig.US_PROD:
                return [
                    device_context_options_1.ProveAuthProxyScriptUrl.DEFAULT_US_PROD_SCRIPT_URL.toString(),
                    device_context_options_1.ProveAuthProxyEndpoint.DEFAULT_US_PROD_ENDPOINT.toString(),
                ];
            case device_context_options_1.BuildConfig.US_UAT:
                return [
                    device_context_options_1.ProveAuthProxyScriptUrl.DEFAULT_US_UAT_SCRIPT_URL.toString(),
                    device_context_options_1.ProveAuthProxyEndpoint.DEFAULT_US_UAT_ENDPOINT.toString(),
                ];
            case device_context_options_1.BuildConfig.DEV:
                this.log.debug("Recommended for Prove's internal testing only, BuildConfig.DEV might need custom endpoint URL and custom script URL values to bypass ad blockers");
                return [undefined, undefined];
            default:
                this.log.warn('Unknown BuildConfig value: ' + buildConfig);
                return [undefined, undefined];
        }
    }
    getRegionByBuildConfig(buildConfig) {
        var region;
        switch (buildConfig) {
            case device_context_options_1.BuildConfig.DEV:
            case device_context_options_1.BuildConfig.US_PROD:
            case device_context_options_1.BuildConfig.US_UAT:
                region = 'us';
                break;
            default:
                this.log.warn('Unknown BuildConfig value, set Region to default value: us');
                region = 'us';
                break;
        }
        return region;
    }
    getFpPromiseInstanceFromOptions(options) {
        try {
            const FingerprintJS = require('@fingerprintjs/fingerprintjs-pro');
            if (!FingerprintJS) {
                this.log.debug('fingerprintjs package is not installed or failed to load');
            }
            else if (!options) {
                this.log.warn('Prove Key Persistence feature is not enabled');
            }
            else {
                let region = this.getRegionByBuildConfig(options.buildConfig);
                let [scriptUrl, endpointUrl] = this.getUrlsByBuildConfig(options.buildConfig);
                if (options.customScriptUrl && options.customEndpointUrl) {
                    scriptUrl = options.customScriptUrl;
                    endpointUrl = options.customEndpointUrl;
                }
                const scriptUrlPattern = scriptUrl
                    ? [
                        `${scriptUrl}?apiKey=<apiKey>&version=<version>&loaderVersion=<loaderVersion>`,
                        FingerprintJS.defaultScriptUrlPattern,
                    ]
                    : [FingerprintJS.defaultScriptUrlPattern];
                const endpoint = endpointUrl
                    ? [`${endpointUrl}?region=${region}`, FingerprintJS.defaultEndpoint]
                    : [FingerprintJS.defaultEndpoint];
                const fpPromise = FingerprintJS.load({
                    apiKey: options.publicApiKey,
                    endpoint: endpoint,
                    scriptUrlPattern: scriptUrlPattern,
                    region: region,
                });
                const status = fpPromise ? 'successfully' : 'unsuccessfully with null instance';
                this.log.trace(`Instantiating FingerprintJS ${status}`);
                return fpPromise;
            }
        }
        catch (error) {
            this.log.trace('FingerprintJS is not installed or failed to load', error);
        }
    }
    withPasskeyAlreadyExistCallback(handler) {
        this.passkeyCreationHandler = handler;
        return this;
    }
    build() {
        var _a;
        if (!this.platform) {
            throw new Error('Implementation of Platform is required');
        }
        if (!this.storage) {
            throw new Error('Implementation of Storage is required');
        }
        const fpPromise = this.getFpPromiseInstanceFromOptions(this.deviceContextOptions);
        if (fpPromise) {
            (_a = this.platform) === null || _a === void 0 ? void 0 : _a.setFpPromise(fpPromise);
        }
        const settings = new settings_1.default(this.storage);
        settings.upkEnabled = this.upkEnabled;
        if (this.role === DeviceRole.Primary) {
            return new main_authenticator_1.default(this.platform, settings, this.authFinishStep, [
                new device_universal_step_1.default(this.upkEnabled),
                new device_universal_redirect_steps_1.DeviceUniversalRedirectExchangeStep(),
                new device_universal_redirect_steps_1.DeviceUniversalRedirectFinishStep(),
                new device_passive_step_1.default(this.getDisplayName, this.passkeyCreationHandler, this.role),
                new device_passive_stepup_step_1.default(this.getDisplayName, this.passkeyCreationHandler),
                new device_passive_silent_step_1.default(this.upkEnabled, this.userConsentStep),
                new device_passive_register_step_1.default(),
                new device_passive_verify_step_1.default(),
                new mobile_instant_step_1.default(this.mobileAuthImplementation, this.getDeviceIp),
                new mobile_instantlink_step_1.default(this.instantLinkStartStep, this.instantLinkRetryStep, this.getDeviceIp),
                new mobile_otp_step_1.default(this.otpStartStep, this.otpFinishStep),
                new user_mobileactive_step_1.default(),
                new scan_message_step_1.default(this.authMessageHandler),
            ]);
        }
        else {
            return new main_authenticator_1.default(this.platform, settings, this.authFinishStep, [
                new device_passive_step_1.default(this.getDisplayName, undefined, this.role),
                new mobile_instant_step_1.default(this.mobileAuthImplementation, this.getDeviceIp),
                new mobile_instantlink_step_1.default(this.instantLinkStartStep, this.instantLinkRetryStep, this.getDeviceIp),
            ]);
        }
    }
}
exports.default = AuthenticatorBuilder;
