"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LoggerFactory = exports.LogLevel = void 0;
var LogLevel;
(function (LogLevel) {
    LogLevel[LogLevel["disabled"] = 0] = "disabled";
    LogLevel[LogLevel["error"] = 1] = "error";
    LogLevel[LogLevel["warn"] = 2] = "warn";
    LogLevel[LogLevel["info"] = 3] = "info";
    LogLevel[LogLevel["debug"] = 4] = "debug";
    LogLevel[LogLevel["trace"] = 5] = "trace";
})(LogLevel = exports.LogLevel || (exports.LogLevel = {}));
class ConsoleLogger {
    trace(...args) {
        console.info(...args);
    }
    debug(...args) {
        console.info(...args);
    }
    info(...args) {
        console.info(...args);
    }
    warn(...args) {
        console.warn(...args);
    }
    error(...args) {
        console.error(...args);
    }
}
class ConsoleLogWriter {
    write(level, ...args) {
        switch (level) {
            case LogLevel.trace:
                console.debug(...args);
                break;
            case LogLevel.debug:
                console.debug(...args);
                break;
            case LogLevel.info:
                console.info(...args);
                break;
            case LogLevel.warn:
                console.warn(...args);
                break;
            case LogLevel.error:
                console.error(...args);
                break;
        }
    }
}
class LoggerFactory {
    static setLogLevel(logLevel) {
        LoggerFactory.logLevel = logLevel;
    }
    static setLogWriter(logWriter) {
        LoggerFactory.logWriter = logWriter;
    }
    static getLogger(name) {
        return {
            trace: (...args) => {
                if (LoggerFactory.logLevel >= LogLevel.trace)
                    LoggerFactory.logWriter.write(LogLevel.trace, name + ': ', ...args);
            },
            debug: (...args) => {
                if (LoggerFactory.logLevel >= LogLevel.debug)
                    LoggerFactory.logWriter.write(LogLevel.debug, name + ': ', ...args);
            },
            info: (...args) => {
                if (LoggerFactory.logLevel >= LogLevel.info)
                    LoggerFactory.logWriter.write(LogLevel.info, name + ': ', ...args);
            },
            warn: (...args) => {
                if (LoggerFactory.logLevel >= LogLevel.warn)
                    LoggerFactory.logWriter.write(LogLevel.warn, name + ': ', ...args);
            },
            error: (...args) => {
                if (LoggerFactory.logLevel >= LogLevel.error)
                    LoggerFactory.logWriter.write(LogLevel.error, name + ': ', ...args);
            },
        };
    }
}
LoggerFactory.logWriter = new ConsoleLogWriter();
LoggerFactory.logLevel = LogLevel.info;
exports.LoggerFactory = LoggerFactory;
