import { MobileAuthImplementation } from '../authenticator-builder';
import { AuthResponseStatus } from './auth-response-status';
export type AuthRequest = V1ClientDeviceFido2RegisterStart | V1ClientDeviceFido2RegisterFinish | V1ClientDeviceFido2VerifyStart | V1ClientDeviceFido2VerifyFinish | V1ClientDevicePassiveRegister | V1ClientDevicePassiveVerify | V1ClientUserResponse | V1ClientAnyError | V1ClientChallenge | V1ClientMobileInstantLinkStart | V1ClientMobileInstantStart | V1ClientMobileInstantFinish | V1ClientOtpStart | V1ClientOtpFinish;
export type AuthRegistration = PassiveRegistration | Fido2Registration;
export interface PublicKey {
    id: string;
    alg: string;
    key: string;
    uvLevel: 0;
}
export interface PassiveRegistration {
    publicKey: PublicKey;
    signature: string;
}
export interface WebAuthnCredentialResponse {
    attestationObject: string;
    clientDataJSON: string;
}
export interface WebAuthnCredential {
    type: string;
    id: string;
    rawId: string;
    response: WebAuthnCredentialResponse;
}
export interface Fido2Registration {
    webAuthnCredential: WebAuthnCredential;
}
export interface V1ClientDeviceFido2RegisterStart {
    displayName?: string;
    signals?: Signals;
}
export interface V1ClientDeviceFido2RegisterFinish {
    deviceName: string;
    deviceCapabilities: string[];
    registrations: AuthRegistration[];
    signals?: Signals;
}
export interface V1ClientDeviceFido2VerifyStart {
    deviceId: string;
}
export interface WebAuthnAssertionResponse {
    authenticatorData: string;
    clientDataJSON: string;
    signature: string;
    userHandle?: string;
}
export interface WebAuthnAssertion {
    type: string;
    id: string;
    rawId: string;
    response: WebAuthnAssertionResponse;
}
export interface V1ClientDeviceFido2VerifyFinish {
    webAuthnAssertion: WebAuthnAssertion;
    signals?: Signals;
}
export interface V1ClientDevicePassiveRegister {
    deviceName: string;
    deviceCapabilities: string[];
    registrations: PassiveRegistration[];
    signals?: Signals;
}
export interface V1ClientDevicePassiveVerify {
    deviceId: string;
    keyId: string;
    signature: string;
    signals?: Signals;
}
export interface V1ClientUserResponse {
    response: AuthResponseStatus;
}
export interface V1ClientAnyError {
    code?: number;
    message: string;
}
export interface V1ClientChallenge {
    deviceId: string;
}
export interface V1ClientMobileInstantLinkStart {
    sourceIp?: string | null;
    mobileNumber?: string | null;
}
export interface V1ClientMobileInstantStart {
    cellularIp?: string | null;
    implementation?: MobileAuthImplementation;
}
export interface V1ClientMobileInstantFinish {
    vfp: string;
}
export interface V1ClientOtpStart {
    mobileNumber?: string | null;
}
export interface V1ClientOtpFinish {
    otp: string;
}
export interface Signals {
    fingerprint?: Signal;
}
export interface Signal {
    results?: string;
    error?: string;
}
