/// <reference types="webappsec-credential-management" />
import AuthMessage from './auth-message';
import { AuthRequest, Signal } from './auth-request';
import AuthResponse from './auth-response';
import AuthTokenClaims, { UserVerificationLevel } from './auth-token-claims';
import { DeviceRegistration } from './device-auth';
import Platform, { AuthSessionIntegration, MessageChannel, RequestSigner } from './platform';
import Settings from './settings';
import { WebSocketCloseReasons } from './web-socket-close-reasons';
export default class AuthSession implements AuthSessionIntegration {
    readonly platform: Platform;
    readonly authToken?: string;
    readonly claims?: AuthTokenClaims;
    readonly settings: Settings;
    readonly requestSigner: RequestSigner;
    readonly channels: Set<MessageChannel>;
    private readonly log;
    lastStep?: string;
    credential?: CredentialType;
    authMessage?: AuthMessage;
    uvLevel?: UserVerificationLevel;
    backendOriginOverride?: string;
    get namespace(): string;
    get backendOrigin(): string;
    get authId(): string;
    get challenge(): string;
    get next(): string;
    constructor(settings: Settings, platform: Platform, authToken?: string);
    fetchFromBackend(query: string, body: AuthRequest): Promise<AuthResponse>;
    static parseCloseEvent(event: CloseEvent): [WebSocketCloseReasons, number];
    createMessageChannel(query: string, onClose: (reason: WebSocketCloseReasons, code: number) => void, onError: (message: string) => void, onMessage: (data: string) => void): MessageChannel;
    closeAllMessageChannels(): void;
    getDeviceRegistration(): Promise<DeviceRegistration | null>;
    embedFpResultToDeviceRegistration(registration: DeviceRegistration): Promise<DeviceRegistration>;
    getFingerprintData(): Promise<Signal | undefined>;
    shouldCollectFP(): boolean;
    private parseJwt;
}
