"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthStatusActions = void 0;
const logger_1 = require("../common/logger");
const auth_error_1 = __importDefault(require("./auth-error"));
class AuthStatusActions {
    constructor() {
        this.log = logger_1.LoggerFactory.getLogger('auth-status-actions');
    }
    waitForStatus(session) {
        var gotResponse = false;
        this.log.trace('Waiting for auth status');
        return new Promise((resolve, reject) => {
            const channel = session.createMessageChannel('/v1/client/status?token=' + encodeURIComponent(session.authToken), (reason, code) => {
                if (!gotResponse) {
                    reject(new auth_error_1.default(`Failed to receive secondary authentication with status code ${code}. ${reason}`));
                }
            }, (errorMessage) => {
                gotResponse = true;
                reject(new auth_error_1.default('Failed to receive secondary authentication status: ' + errorMessage));
            }, (data) => {
                gotResponse = true;
                try {
                    this.log.debug(('Secondary authentication status: ' + data));
                    const response = JSON.parse(data);
                    if (response.error) {
                        reject(new auth_error_1.default(response.error.message, response.error.code, response.next, false));
                    }
                    else {
                        session.lastStep = response.next;
                        resolve(response.next);
                    }
                }
                catch (e) {
                    reject(e);
                }
                finally {
                    this.log.trace('Closing channel');
                    channel.close();
                }
            });
        });
    }
}
exports.AuthStatusActions = AuthStatusActions;
