"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("../common/logger");
const device_passive_step_1 = require("./device-passive-step");
class DevicePassiveStepupStep extends device_passive_step_1.DevicePassiveActions {
    constructor(getDisplayName, handler) {
        super(getDisplayName, handler);
        this.name = DevicePassiveStepupStep.NAME;
        this.log = logger_1.LoggerFactory.getLogger('device-passive-stepup-step');
    }
    execute(session) {
        if (!session.platform.isFidoSupported()) {
            return Promise.reject(new Error('FIDO2 is not supported'));
        }
        if (!session.settings.deviceId) {
            return Promise.reject(new Error('Device is not registered'));
        }
        if (session.settings.fidoPasskeyRegistered) {
            return Promise.reject(new Error('FIDO2 Passkey is already registered'));
        }
        return new Promise((resolve, reject) => {
            session
                .getFingerprintData()
                .then((signal) => {
                const signals = {
                    fingerprint: signal,
                };
                this.register(session, signals).then(resolve).catch(reject);
            })
                .catch((error) => {
                const errorMsg = `Unexpected error happened during Fingerprint data collection: ${error.message}`;
                this.log.warn(errorMsg);
                this.log.warn(error);
                const signals = {
                    fingerprint: {
                        error: errorMsg,
                    },
                };
                this.register(session, signals).then(resolve).catch(reject);
            });
        });
    }
}
DevicePassiveStepupStep.NAME = 'device/passive/stepup';
exports.default = DevicePassiveStepupStep;
