/// <reference types="webappsec-credential-management" />
import { AuthenticatorBuilder } from '@prove-identity/mobile-auth';
import { AuthRequest } from './auth-request';
import AuthResponse from './auth-response';
import DeviceAuth, { DeviceRegistration } from './device-auth';
import { Agent } from '@fingerprintjs/fingerprintjs-pro';
export declare const DEVICE_CAPABILITY_WEBAUTHN = "webauthn";
export interface MessageChannel {
    addEventListener: (type: string, listener: (event: any) => void) => void;
    send: (data: string) => void;
    close: () => void;
}
export interface WebAuthN {
    getCredentials: (options?: CredentialRequestOptions) => Promise<CredentialType | null>;
    createCredentials: (options: CredentialCreationOptions) => Promise<CredentialType | null>;
}
export interface RequestSignature {
    version: string;
    challenge: string;
    keyId: string;
    signature: string;
}
export interface RequestSigner {
    sign: (method: string, path: string, query: string, contentType: string, body: string) => Promise<RequestSignature | null>;
}
export interface AuthSessionIntegration {
    getDeviceRegistration: () => Promise<DeviceRegistration | null>;
    fetchFromBackend: (query: string, body: AuthRequest) => Promise<AuthResponse>;
}
export default interface Platform {
    readonly webauthn: WebAuthN;
    readonly deviceAuth: DeviceAuth;
    getPlatformName: () => string;
    getUserAgent: () => string | null;
    isFidoSupported: () => boolean;
    fetch: (input: string, init?: RequestInit) => Promise<Response>;
    createMessageChannel: (input: string) => MessageChannel;
    createRequestSigner: (session: AuthSessionIntegration) => RequestSigner;
    getDeviceCapabilities: () => string[];
    getMobileAuthBuilder: () => AuthenticatorBuilder<any>;
    exit: (code?: number) => void;
    urlRedirect: (url: string) => void;
    getFpPromise: () => Promise<Agent> | undefined;
    setFpPromise: (fpPromise: Promise<Agent>) => void;
    getOrigin: () => string;
}
export declare function stringToArrayBuffer(input: string): ArrayBuffer;
export declare function arrayBufferToString(input: ArrayBuffer): string;
export declare function arrayBufferToHexString(input: ArrayBuffer): string;
export declare function getUnixTime(): number;
