"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("../common/logger");
const auth_error_1 = __importDefault(require("./auth-error"));
const main_authenticator_1 = __importDefault(require("./main-authenticator"));
const device_passive_register_step_1 = __importDefault(require("./device-passive-register-step"));
const device_passive_silent_step_1 = __importDefault(require("./device-passive-silent-step"));
const device_passive_step_1 = __importDefault(require("./device-passive-step"));
const device_passive_verify_step_1 = __importDefault(require("./device-passive-verify-step"));
const mobile_instant_step_1 = __importDefault(require("./mobile-instant-step"));
const mobile_instantlink_step_1 = __importDefault(require("./mobile-instantlink-step"));
const mobile_otp_step_1 = __importDefault(require("./mobile-otp-step"));
const user_present_step_1 = __importDefault(require("./user-present-step"));
const device_passive_stepup_step_1 = __importDefault(require("./device-passive-stepup-step"));
const device_universal_redirect_steps_1 = require("./device-universal-redirect-steps");
class ReportErrorStep {
    constructor(error) {
        this.logger = logger_1.LoggerFactory.getLogger('report-error-step');
        this._message = 'Unknown error';
        this.reportable = true;
        this.name = 'error';
        if (error instanceof auth_error_1.default) {
            const authError = error;
            this._message = authError.message;
            this._code = authError.code;
            this.nextStep = authError.nextStep;
            this.reportable = authError.reportable;
        }
        else if (error) {
            this._message = auth_error_1.default.extractMessage(error);
        }
        if (!this._message) {
            this.logger.warn('Unexpected error: ' + error);
        }
    }
    get code() {
        return this._code;
    }
    get message() {
        return this._message;
    }
    execute(session) {
        let logMessage = `Authentication step ${session.lastStep} failed`;
        if (this._code) {
            logMessage = logMessage + ', code: ' + this._code;
        }
        if (this._message) {
            logMessage = logMessage + ', message: ' + this._message;
        }
        this.logger.error(logMessage);
        if (this.nextStep === main_authenticator_1.default.AUTH_DONE) {
            return Promise.resolve(main_authenticator_1.default.AUTH_DONE);
        }
        const endpoint = session.lastStep
            ? ReportErrorStep.endpointMap.get(session.lastStep)
            : undefined;
        if (endpoint && (this.reportable || !this.nextStep)) {
            return new Promise((resolve, reject) => {
                session
                    .fetchFromBackend(`/v1/client/${endpoint}/error`, {
                    code: this._code ? this._code : undefined,
                    message: this._message,
                })
                    .then((response) => resolve(response.next))
                    .catch(reject);
            });
        }
        else if (this.nextStep) {
            return Promise.resolve(this.nextStep);
        }
        else {
            return Promise.reject(new auth_error_1.default('Cannot determine the next auth step'));
        }
    }
}
ReportErrorStep.endpointMap = new Map([
    [device_passive_step_1.default.NAME, 'device/passive'],
    [device_passive_silent_step_1.default.NAME, 'device/passive'],
    [device_passive_register_step_1.default.NAME, 'device/fido2'],
    [device_passive_verify_step_1.default.NAME, 'device/fido2'],
    [device_passive_stepup_step_1.default.NAME, 'device/fido2'],
    [mobile_instant_step_1.default.NAME, 'mobile/instant'],
    [mobile_instantlink_step_1.default.NAME, 'mobile/instantlink'],
    [mobile_otp_step_1.default.NAME, 'mobile/otp'],
    [user_present_step_1.default.NAME, 'user/mobileactive'],
    [device_universal_redirect_steps_1.DeviceUniversalRedirectExchangeStep.NAME, 'device/universal'],
    [device_universal_redirect_steps_1.DeviceUniversalRedirectFinishStep.NAME, 'device/universal'],
]);
exports.default = ReportErrorStep;
