"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const auth_error_1 = __importDefault(require("./auth-error"));
const logger_1 = require("../common/logger");
class ScanMessageStep {
    constructor(authMessageHandler) {
        this.log = logger_1.LoggerFactory.getLogger('scan-message-step');
        this.name = ScanMessageStep.NAME;
        this.authMessageHandler = authMessageHandler;
    }
    execute(session) {
        return new Promise((resolve, reject) => {
            if (!this.authMessageHandler) {
                reject(new auth_error_1.default('Failed to process auth message, the handler was not specified'));
            }
            else {
                if (!session.authMessage) {
                    this.log.warn('Auth message is missing');
                    session.authMessage = {};
                }
                this.authMessageHandler(session.authMessage)
                    .then((status) => {
                    session
                        .fetchFromBackend('/v1/client/user/response', {
                        response: status,
                    })
                        .then((response) => {
                        if (response.error) {
                            reject(new auth_error_1.default(response.error.message, response.error.code, response.next, false));
                        }
                        else {
                            resolve(response.next);
                        }
                    });
                })
                    .catch(reject);
            }
        });
    }
}
ScanMessageStep.NAME = 'scan/message';
exports.default = ScanMessageStep;
