"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebPlatform = exports.WebSocketMessageChannel = void 0;
const mobile_auth_1 = require("@prove-identity/mobile-auth");
const platform_1 = require("./platform");
const request_signer_v3_1 = __importDefault(require("./request-signer-v3"));
const web_device_auth_1 = __importDefault(require("./web-device-auth"));
class WebSocketMessageChannel {
    constructor(endpointUrl) {
        this.webSocket = new WebSocket(endpointUrl);
    }
    addEventListener(type, listener) {
        this.webSocket.addEventListener(type, listener);
    }
    send(data) {
        this.webSocket.send(data);
    }
    close() {
        this.webSocket.close();
    }
}
exports.WebSocketMessageChannel = WebSocketMessageChannel;
class WebPlatform {
    constructor() {
        this.webauthn = {
            getCredentials: (options) => {
                return navigator.credentials.get(options);
            },
            createCredentials: (options) => {
                return navigator.credentials.create(options);
            },
        };
        this.deviceAuth = new web_device_auth_1.default(window.indexedDB);
    }
    getPlatformName() {
        return `${this.getBrowserName()} ${this.getBrowserVersion()} on ${this.getOSName()}`;
    }
    getUserAgent() {
        return navigator.userAgent;
    }
    isFidoSupported() {
        return window.PublicKeyCredential != undefined;
    }
    fetch(input, init) {
        return fetch(input, init);
    }
    createMessageChannel(input) {
        return new WebSocketMessageChannel(input);
    }
    createRequestSigner(session) {
        return new request_signer_v3_1.default(session);
    }
    getBrowserName() {
        const agent = navigator.userAgent;
        let browserName;
        if (agent.indexOf('Firefox') > -1) {
            browserName = 'Firefox';
        }
        else if (agent.indexOf('Opera') > -1 || agent.indexOf('OPR') > -1) {
            browserName = 'Opera';
        }
        else if (agent.indexOf('DuckDuckGo') > -1) {
            browserName = 'DuckDuckGo';
        }
        else if (agent.indexOf('SamsungBrowser') > -1) {
            browserName = 'Samsung Browser';
        }
        else if (agent.indexOf('Trident') > -1) {
            browserName = 'Internet Explorer';
        }
        else if (agent.indexOf('Edge') > -1) {
            browserName = 'Edge';
        }
        else if (agent.indexOf('Chrome') > -1) {
            browserName = 'Chrome';
        }
        else if (agent.indexOf('Safari') > -1) {
            browserName = 'Safari';
        }
        else {
            browserName = 'Unknown';
        }
        return browserName;
    }
    getBrowserVersion() {
        const agent = navigator.userAgent;
        const verRegex = /(?:Firefox|Opera|OPR|SamsungBrowser|DuckDuckGo|Internet Explorer|Edge|Chrome|Safari)[\/|\s](\d+(\.\d+)?)/i;
        const matches = agent.match(verRegex);
        return matches ? matches[1] : 'Unknown';
    }
    getOSName() {
        const platform = navigator.platform;
        const agent = navigator.userAgent;
        let osName;
        if (/Win/i.test(platform)) {
            osName = 'Windows';
            const matches = agent.match(/Win(?:dows )?NT (\d+\.\d+)/i);
            if (matches) {
                const windowsVersion = parseFloat(matches[1]);
                if (windowsVersion === 11) {
                    osName += ' 11';
                }
                else if (windowsVersion === 10) {
                    osName += ' 10';
                }
                else if (windowsVersion === 6.3) {
                    osName += ' 8.1';
                }
                else if (windowsVersion === 6.2) {
                    osName += ' 8';
                }
                else if (windowsVersion === 6.1) {
                    osName += ' 7';
                }
                else if (windowsVersion === 6.0) {
                    osName += ' Vista';
                }
                else if (windowsVersion === 5.1 || windowsVersion === 5.2) {
                    osName += ' XP';
                }
                else {
                    osName += ' (Unknown Version)';
                }
            }
        }
        else if (platform.match(/Mac/i)) {
            osName = 'Mac OS';
            const matches = agent.match(/Mac OS X (\d+[_.]\d+([_.]\d+)?)/i);
            if (matches) {
                const macVersion = matches[1].replace(/_/g, '.');
                osName += ' ' + macVersion;
            }
        }
        else if (agent.match(/Android/i)) {
            osName = 'Android';
        }
        else if (agent.match(/iOS|iPhone|iPad|iPod/i)) {
            osName = 'iOS';
        }
        else if (platform.match(/Linux/i)) {
            osName = 'Linux';
        }
        else {
            osName = 'Unknown';
        }
        return osName;
    }
    getDeviceCapabilities() {
        return this.isFidoSupported() ? [platform_1.DEVICE_CAPABILITY_WEBAUTHN] : [];
    }
    getMobileAuthBuilder() {
        return new mobile_auth_1.AuthenticatorBuilder();
    }
    exit(code) {
    }
    urlRedirect(url) {
        window.location.replace(url);
    }
    getFpPromise() {
        return this.fpPromise;
    }
    setFpPromise(fpPromise) {
        this.fpPromise = fpPromise;
    }
    getOrigin() {
        return window.location.origin;
    }
}
exports.WebPlatform = WebPlatform;
